Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(726)

Unified Diff: net/url_request/url_request_unittest.cc

Issue 9188019: Cleanup: Rename is_hsts_host to fatal. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/url_request_test_util.cc ('k') | webkit/fileapi/file_writer_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_request_unittest.cc
===================================================================
--- net/url_request/url_request_unittest.cc (revision 117302)
+++ net/url_request/url_request_unittest.cc (working copy)
@@ -1082,9 +1082,9 @@
}
}
// This tests that a load of www.google.com with a certificate error sets the
// is_hsts_host flag correctly. This flag will cause the interstitial to be
// fatal.
TEST_F(HTTPSRequestTest, HTTPSPreloadedHSTSTest) {
TestServer::HTTPSOptions https_options(
TestServer::HTTPSOptions::CERT_MISMATCHED_NAME);
@@ -1121,7 +1121,7 @@
EXPECT_EQ(1, d.response_started_count());
EXPECT_FALSE(d.received_data_before_response());
EXPECT_TRUE(d.have_certificate_errors());
- EXPECT_TRUE(d.is_hsts_host());
+ EXPECT_TRUE(d.certificate_errors_are_fatal());
}
namespace {
« no previous file with comments | « net/url_request/url_request_test_util.cc ('k') | webkit/fileapi/file_writer_delegate.h » ('j') | no next file with comments »
@@ -1082,9 +1082,9 @@
}
}
-// This tests that a load of www.google.com with a certificate error sets the
-// is_hsts_host flag correctly. This flag will cause the interstitial to be
-// fatal.
+// This tests that a load of www.google.com with a certificate error sets
+// the |certificate_errors_are_fatal| flag correctly. This flag will cause
+// the interstitial to be fatal.
TEST_F(HTTPSRequestTest, HTTPSPreloadedHSTSTest) {
TestServer::HTTPSOptions https_options(

Powered by Google App Engine
This is Rietveld 408576698